# Transitions

A transition connects two steps in a workflow.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Name:
The name of the transition.

### From:
The originating step.

### To:
The target step.

### Icon:
The icon that will grace the transition buttons for user steps.

## Filters:
Filters are accessed by clicking on the symbol in the top left corner of the window.

### Associated Condition:
Displays the transition a selected condition is attached to.

## Search Field:
Typing in the search field allows to filter the transitions by name.
